==> blancoNLpackGenerator-0.1.6-src.zip: src/blanco/nlpack/generator/message/BlancoNLpackGeneratorMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.nlpack.generator.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoNLpackGeneratorMessage/bZ[W`[BlancoNLpackGenerator]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoNLpackGeneratorMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoNLpackGeneratorMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGeneratorMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoNLpackGeneratorMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGeneratorMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoNLpackGeneratorMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoNLpackGeneratorMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI001]
     *
     * [sourcedirƂĎw肳ꂽfBNg[{0}]݂͑܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBI001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "sourcedirƂĎw肳ꂽfBNg[{0}]݂͑܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI003]
     *
     * [^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBI003]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi003(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI003");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI004]
     *
     * [ʃOt@CET}({0})̍쐬Ɏs܂B:{1}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBI004]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi004(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ʃOt@CET}({0})̍쐬Ɏs܂B:{1}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI004");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI005]
     *
     * [ʃOt@CEڍ({0})̍쐬Ɏs܂B:{1}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBI005]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi005(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ʃOt@CEڍ({0})̍쐬Ɏs܂B:{1}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI005");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC001]
     *
     * [CSVt@Co̍ۂɗO܂B:{0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBC001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "CSVt@Co̍ۂɗO܂B:{0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC002]
     *
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(͂ null^悤Ƃ܂B)] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBC002]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc002(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(͂ null^悤Ƃ܂B)";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC002");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC003]
     *
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(o͂ null^悤Ƃ܂B)] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBC003]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc003(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(o͂ null^悤Ƃ܂B)";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC003");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBP001]
     *
     * [Pleiades̓ǂݍݏɎs܂B(PleiadesNX̃[hɎsꍇ ֘ANX̃[hɎsA邢 conffBNg̓ǂݍ݂ɎsȂǂ̌ۂz肳܂B): {0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBP001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebp001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Pleiades̓ǂݍݏɎs܂B(PleiadesNX̃[hɎsꍇ ֘ANX̃[hɎsA邢 conffBNg̓ǂݍ݂ɎsȂǂ̌ۂz肳܂B): {0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBP001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBMO01]
     *
     * [O[{0}]̃[hɎs܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBMO01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebmo01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[{0}]̃[hɎs܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBMO01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBMO02]
     *
     * [Oǂݍݏɂ CSVO܂B: {0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBMO02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebmo02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Oǂݍݏɂ CSVO܂B: {0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBMO02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}

==> blancoNLpackGenerator-0.1.21-src.zip: src/blanco/nlpack/generator/message/BlancoNLpackGeneratorMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.nlpack.generator.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoNLpackGeneratorMessage/bZ[W`[BlancoNLpackGenerator]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoNLpackGeneratorMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoNLpackGeneratorMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/message/BlancoNLpackGeneratorMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoNLpackGeneratorMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/message/BlancoNLpackGeneratorMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoNLpackGeneratorMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoNLpackGeneratorMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoNLpackGeneratorMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/nlpack/generator/message/BlancoNLpackGeneratorMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI001]
     *
     * [sourcedirƂĎw肳ꂽfBNg[{0}]݂͑܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBI001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "sourcedirƂĎw肳ꂽfBNg[{0}]݂͑܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI003]
     *
     * [^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBI003]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi003(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^ꂽt@C[{0}] [.jar]ŏIĂ܂B[.jar]ŏIt@C^ĂB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI003");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI004]
     *
     * [ʃOt@CET}({0})̍쐬Ɏs܂B:{1}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBI004]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi004(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ʃOt@CET}({0})̍쐬Ɏs܂B:{1}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI004");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBI005]
     *
     * [ʃOt@CEڍ({0})̍쐬Ɏs܂B:{1}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBI005]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebi005(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "ʃOt@CEڍ({0})̍쐬Ɏs܂B:{1}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBI005");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC001]
     *
     * [CSVt@Co̍ۂɗO܂B:{0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBC001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "CSVt@Co̍ۂɗO܂B:{0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC002]
     *
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(͂ null^悤Ƃ܂B)] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBC002]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc002(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(͂ null^悤Ƃ܂B)";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC002");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBC003]
     *
     * [vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(o͂ null^悤Ƃ܂B)] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBEBC003]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebc003(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "vOŒʉ߂Ă͂ȂȂӏʉ߂悤Ƃ܂BohURI[{0}]AL[[{1}]B(o͂ null^悤Ƃ܂B)";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBC003");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBP001]
     *
     * [Pleiades̓ǂݍݏɎs܂B(PleiadesNX̃[hɎsꍇ ֘ANX̃[hɎsA邢 conffBNg̓ǂݍ݂ɎsȂǂ̌ۂz肳܂B): {0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBP001]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebp001(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Pleiades̓ǂݍݏɎs܂B(PleiadesNX̃[hɎsꍇ ֘ANX̃[hɎsA邢 conffBNg̓ǂݍ݂ɎsȂǂ̌ۂz肳܂B): {0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBP001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBMO01]
     *
     * [O[{0}]̃[hɎs܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBMO01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebmo01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[{0}]̃[hɎs܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBMO01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoNLpackGeneratorMessage], key[MBEBMO02]
     *
     * [Oǂݍݏɂ CSVO܂B: {0}] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBEBMO02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbebmo02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "Oǂݍݏɂ CSVO܂B: {0}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBEBMO02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}
